==> request-tracker4_4.4.6+dfsg.orig-third-party-source.tar.gz: rt-4.4.6/devel/third-party/ckeditor-src/plugins/link/lang/gu.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'gu', {
	acccessKey: 'ઍક્સેસ કી',
	advanced: 'અડ્વાન્સડ',
	advisoryContentType: 'મુખ્ય કન્ટેન્ટ પ્રકાર',
	advisoryTitle: 'મુખ્ય મથાળું',
	anchor: {
		toolbar: 'ઍંકર ઇન્સર્ટ/દાખલ કરવી',
		menu: 'ઍંકરના ગુણ',
		title: 'ઍંકરના ગુણ',
		name: 'ઍંકરનું નામ',
		errorName: 'ઍંકરનું નામ ટાઈપ કરો',
		remove: 'સ્થિર નકરવું'
	},
	anchorId: 'ઍંકર એલિમન્ટ Id થી પસંદ કરો',
	anchorName: 'ઍંકર નામથી પસંદ કરો',
	charset: 'લિંક રિસૉર્સ કૅરિક્ટર સેટ',
	cssClasses: 'સ્ટાઇલ-શીટ ક્લાસ',
	emailAddress: 'ઈ-મેલ સરનામું',
	emailBody: 'સંદેશ',
	emailSubject: 'ઈ-મેલ વિષય',
	id: 'Id',
	info: 'લિંક ઇન્ફૉ ટૅબ',
	langCode: 'ભાષા લેખવાની પદ્ધતિ',
	langDir: 'ભાષા લેખવાની પદ્ધતિ',
	langDirLTR: 'ડાબે થી જમણે (LTR)',
	langDirRTL: 'જમણે થી ડાબે (RTL)',
	menu: ' લિંક એડિટ/માં ફેરફાર કરવો',
	name: 'નામ',
	noAnchors: '(ડૉક્યુમન્ટમાં ઍંકરની સંખ્યા)',
	noEmail: 'ઈ-મેલ સરનામું ટાઇપ કરો',
	noUrl: 'લિંક  URL ટાઇપ કરો',
	other: '<other> <અન્ય>',
	popupDependent: 'ડિપેન્ડન્ટ (Netscape)',
	popupFeatures: 'પૉપ-અપ વિન્ડો ફીચરસૅ',
	popupFullScreen: 'ફુલ સ્ક્રીન (IE)',
	popupLeft: 'ડાબી બાજુ',
	popupLocationBar: 'લોકેશન બાર',
	popupMenuBar: 'મેન્યૂ બાર',
	popupResizable: 'રીસાઈઝએબલ',
	popupScrollBars: 'સ્ક્રોલ બાર',
	popupStatusBar: 'સ્ટૅટસ બાર',
	popupToolbar: 'ટૂલ બાર',
	popupTop: 'જમણી બાજુ',
	rel: 'સંબંધની સ્થિતિ',
	selectAnchor: 'ઍંકર પસંદ કરો',
	styles: 'સ્ટાઇલ',
	tabIndex: 'ટૅબ ઇન્ડેક્સ',
	target: 'ટાર્ગેટ/લક્ષ્ય',
	targetFrame: '<ફ્રેમ>',
	targetFrameName: 'ટાર્ગેટ ફ્રેમ નું નામ',
	targetPopup: '<પૉપ-અપ વિન્ડો>',
	targetPopupName: 'પૉપ-અપ વિન્ડો નું નામ',
	title: 'લિંક',
	toAnchor: 'આ પેજનો ઍંકર',
	toEmail: 'ઈ-મેલ',
	toUrl: 'URL',
	toolbar: 'લિંક ઇન્સર્ટ/દાખલ કરવી',
	type: 'લિંક પ્રકાર',
	unlink: 'લિંક કાઢવી',
	upload: 'અપલોડ'
} );

==> request-tracker5_5.0.7+dfsg.orig-third-party-source.tar.gz: rt-5.0.7/devel/third-party/ckeditor-src/plugins/link/lang/gu.js <==
﻿/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'gu', {
	acccessKey: 'ઍક્સેસ કી',
	advanced: 'અડ્વાન્સડ',
	advisoryContentType: 'મુખ્ય કન્ટેન્ટ પ્રકાર',
	advisoryTitle: 'મુખ્ય મથાળું',
	anchor: {
		toolbar: 'ઍંકર ઇન્સર્ટ/દાખલ કરવી',
		menu: 'ઍંકરના ગુણ',
		title: 'ઍંકરના ગુણ',
		name: 'ઍંકરનું નામ',
		errorName: 'ઍંકરનું નામ ટાઈપ કરો',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'સ્થિર નકરવું'
	},
	anchorId: 'ઍંકર એલિમન્ટ Id થી પસંદ કરો',
	anchorName: 'ઍંકર નામથી પસંદ કરો',
	charset: 'લિંક રિસૉર્સ કૅરિક્ટર સેટ',
	cssClasses: 'સ્ટાઇલ-શીટ ક્લાસ',
	download: 'ડાઉનલોડ કરો',
	displayText: 'લખાણ દેખાડો',
	emailAddress: 'ઈ-મેલ સરનામું',
	emailBody: 'સંદેશ',
	emailSubject: 'ઈ-મેલ વિષય',
	id: 'Id',
	info: 'લિંક ઇન્ફૉ ટૅબ',
	langCode: 'ભાષા લેખવાની પદ્ધતિ',
	langDir: 'ભાષા લેખવાની પદ્ધતિ',
	langDirLTR: 'ડાબે થી જમણે (LTR)',
	langDirRTL: 'જમણે થી ડાબે (RTL)',
	menu: ' લિંક એડિટ/માં ફેરફાર કરવો',
	name: 'નામ',
	noAnchors: '(ડૉક્યુમન્ટમાં ઍંકરની સંખ્યા)',
	noEmail: 'ઈ-મેલ સરનામું ટાઇપ કરો',
	noUrl: 'લિંક  URL ટાઇપ કરો',
	noTel: 'Please type the phone number', // MISSING
	other: '<other> <અન્ય>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'ડિપેન્ડન્ટ (Netscape)',
	popupFeatures: 'પૉપ-અપ વિન્ડો ફીચરસૅ',
	popupFullScreen: 'ફુલ સ્ક્રીન (IE)',
	popupLeft: 'ડાબી બાજુ',
	popupLocationBar: 'લોકેશન બાર',
	popupMenuBar: 'મેન્યૂ બાર',
	popupResizable: 'રીસાઈઝએબલ',
	popupScrollBars: 'સ્ક્રોલ બાર',
	popupStatusBar: 'સ્ટૅટસ બાર',
	popupToolbar: 'ટૂલ બાર',
	popupTop: 'જમણી બાજુ',
	rel: 'સંબંધની સ્થિતિ',
	selectAnchor: 'ઍંકર પસંદ કરો',
	styles: 'સ્ટાઇલ',
	tabIndex: 'ટૅબ ઇન્ડેક્સ',
	target: 'ટાર્ગેટ/લક્ષ્ય',
	targetFrame: '<ફ્રેમ>',
	targetFrameName: 'ટાર્ગેટ ફ્રેમ નું નામ',
	targetPopup: '<પૉપ-અપ વિન્ડો>',
	targetPopupName: 'પૉપ-અપ વિન્ડો નું નામ',
	title: 'લિંક',
	toAnchor: 'આ પેજનો ઍંકર',
	toEmail: 'ઈ-મેલ',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'લિંક ઇન્સર્ટ/દાખલ કરવી',
	type: 'લિંક પ્રકાર',
	unlink: 'લિંક કાઢવી',
	upload: 'અપલોડ'
} );
